package org.jtheque.core.managers.core.io;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.utils.io.FileUtils;

import java.io.File;

/**
 * Give access to the folders of the application.
 *
 * @author Baptiste Wicht
 */
public final class Folders implements IFoldersContainer {
    private File applicationFolder;
    private File librairiesFolder;
    private File modulesFolder;
    private File skinsFolder;
    private File logsFolder;
    private File cacheFolder;

    @Override
    public File getApplicationFolder() {
        if (applicationFolder == null) {
            applicationFolder = new File(Managers.getCore().getApplication().getFolderPath());

            FileUtils.createIfNotExists(applicationFolder);
        }

        return applicationFolder;
    }

    @Override
    public File getSkinsFolder() {
        if (skinsFolder == null) {
            skinsFolder = new File(getApplicationFolder(), "/skins");

            FileUtils.createIfNotExists(skinsFolder);
        }

        return skinsFolder;
    }

    @Override
    public File getLogsFolder() {
        if (logsFolder == null) {
            logsFolder = new File(getApplicationFolder(), "/logs");

            FileUtils.createIfNotExists(logsFolder);
        }

        return logsFolder;
    }

    @Override
    public File getLibrairiesFolder() {
        if (librairiesFolder == null) {
            librairiesFolder = new File(getApplicationFolder(), "/lib");

            FileUtils.createIfNotExists(librairiesFolder);
        }

        return librairiesFolder;
    }

    @Override
    public File getModulesFolder() {
        if (modulesFolder == null) {
            modulesFolder = new File(getApplicationFolder(), "/modules");

            FileUtils.createIfNotExists(modulesFolder);
        }

        return modulesFolder;
    }

    @Override
    public File getCacheFolder() {
        if (cacheFolder == null) {
            cacheFolder = new File(getApplicationFolder(), "/cache");

            FileUtils.createIfNotExists(cacheFolder);
        }

        return cacheFolder;
    }

    @Override
    public String getTempFolderPath() {
        return System.getProperty("java.io.tmpdir");
    }
}