package org.jtheque.core.managers.log;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.apache.log4j.Logger;

/**
 * A JTheque Logger. This logger is based on a Log4J logger.
 *
 * @author Baptiste Wicht
 */
public final class JThequeLogger implements IJThequeLogger {
    private final Logger logger;

    /**
     * Construct a new <code>MyLogger</code>.
     *
     * @param callerClass The class who want to obtain a logger.
     */
    public JThequeLogger(final Class<?> callerClass) {
        super();

        logger = Logger.getLogger(callerClass);
    }

    @Override
    public void message(String message) {
        logger.info(message);
    }

    @Override
    public void exception(Throwable e) {
        logger.error(e.getMessage(), e);
    }

    @Override
    public void error(String message) {
        logger.error(message);
    }

    @Override
    public void debug(String message) {
        logger.debug(message);
    }

    @Override
    public void trace(String message) {
        logger.trace(message);
    }

    @Override
    public void fatal(String message) {
        logger.fatal(message);
    }

    @Override
    public void warn(String message) {
        logger.warn(message);
    }

    @Override
    public void error(String message, Exception e) {
        logger.error(message, e);
    }
}