package org.jtheque.core.managers.skin;

import java.util.List;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * A Skin Manager specification.
 *
 * @author Baptiste Wicht
 */
public interface ISkinManager {
    /**
     * Return all the look and feel loaded.
     *
     * @return The availables look and feels
     */
    List<Skin> getSkins();

    /**
     * Apply the look and feel to the application.
     *
     * @param skin The look and feel to apply
     */
    void setSkin(Skin skin);

    /**
     * Return the current look and feel.
     *
     * @return The current look and feel
     */
    Skin getCurrentSkin();

    /**
     * Add a skin listener. 
     * 
     * @param listener A skin listener. 
     */
    void addSkinListener(SkinListener listener);

    /**
     * Remove a skin listener. 
     * 
     * @param listener The skin listener to remove. 
     */
    void removeSkinListener(SkinListener listener);
}