package org.jtheque.core.managers.view.impl.components;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;

import org.jdesktop.swinghelper.layer.JXLayer;

import javax.swing.JComponent;
import javax.swing.JTabbedPane;
import java.util.ArrayList;
import java.util.List;

/**
 * A tabbedpane with different layer.
 *
 * @author Baptiste Wicht
 */
public class LayerTabbedPane extends JTabbedPane {
    private static final long serialVersionUID = -5183713814998385959L;

    private final List<JXLayer<JComponent>> components;

    /**
     * Construct a new LayerTabbedPane.
     */
    public LayerTabbedPane() {
        super();

        components = new ArrayList<JXLayer<JComponent>>(5);

        addChangeListener(new TabbedAnimatingChangeListener());
    }

    /**
     * Add an internationalized tab. 
     * 
     * @param key The internationalization key. 
     * @param component The component to add. 
     */
    public final void addInternationalizedTab(String key, JComponent component){
        addTab(Managers.getManager(ILanguageManager.class).getMessage(key), component);
    }

    /**
     * Add a tab.
     *
     * @param title     The title of the tab.
     * @param component The tab component.
     */
    public final void addTab(String title, JComponent component) {
        JXLayer<JComponent> layerComponent = new JXLayer<JComponent>(component);

        components.add(layerComponent);
        super.addTab(title, layerComponent);
    }

    /**
     * Return the selected component.
     *
     * @return the selected component.
     */
    @Override
    public final JComponent getSelectedComponent() {
        if (getSelectedIndex() != -1) {
            return components.get(getSelectedIndex()).getView();
        }

        return null;
    }

    /**
     * Return the selected layer.
     *
     * @return the selected layer or null if there is no selected layer.
     */
    public final JXLayer<JComponent> getSelectedLayer() {
        JXLayer<JComponent> layer = null;

        if (getSelectedIndex() != -1) {
            layer = components.get(getSelectedIndex());
        }

        return layer;
    }

    /**
     * Return the layer at a certain index.
     *
     * @param index The index for which we search the layer.
     * @return the corresponding layer.
     */
    public final JXLayer<JComponent> getLayerAt(int index) {
        return components.get(index);
    }
}