package org.jtheque.core.managers.view.impl.components;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swinghelper.layer.JXLayer;
import org.jdesktop.swinghelper.layer.painter.ComponentPainter;
import org.jdesktop.swinghelper.layer.painter.model.PainterModel;

import javax.swing.JComponent;
import javax.swing.Timer;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import java.awt.Graphics2D;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * A listener for JTabbedPane. This listener display an animation when the selected tab change.
 *
 * @author Baptiste Wicht
 */
final class TabbedAnimatingChangeListener implements ChangeListener {
    private int index;
    private final Timer timer;
    private final ComponentPainter<JComponent> painter;
    private static final int CHANGE_INTERVAL = 25;

    /**
     * Construct a new TabbedAnimatingChangeListener.
     */
    TabbedAnimatingChangeListener() {
        painter = new AnimationPainter();

        timer = new Timer(CHANGE_INTERVAL, new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                painter.update();
                PainterModel model = painter.getModel();

                if (model.getAlpha() <= .1f) {
                    model.setAlpha(0);
                    timer.stop();
                    return;
                }

                model.setAlpha(model.getAlpha() - .1f);
            }
        });
    }

    @Override
    public void stateChanged(ChangeEvent e) {
        LayerTabbedPane pane = (LayerTabbedPane) e.getSource();
        JXLayer<JComponent> layer = pane.getSelectedLayer();

        if (layer != null) {
            JXLayer<JComponent> oldLayer = pane.getLayerAt(index);

            PainterModel model = painter.getModel();
            model.setAlpha(1 - model.getAlpha());

            painter.setComponent(oldLayer);

            oldLayer.setPainter(layer.getPainter());
            layer.setPainter(painter);

            painter.update();
            timer.start();
            index = pane.getSelectedIndex();
        }
    }

    /**
     * A painter for animation.
     *
     * @author Baptiste Wicht
     */
    static final class AnimationPainter extends ComponentPainter<JComponent> {
        /**
         * Construct a new AnimationPainter.
         */
        AnimationPainter() {
            super();

            getModel().setAlpha(0);
        }

        @Override
        public void paint(Graphics2D g2, JXLayer<JComponent> l) {
            // paint the layer
            l.paint(g2);
            // paint the old layer with diminishing alpha
            super.paint(g2, l);
        }
    }
}